Calculates all HRT parameters needed for an HRT object and saves them in the corresponding slots.
calcHRTParams(HRTObj, IL = c_normIL, normIL = c_normIL)# S4 method for HRT
calcHRTParams(HRTObj, IL = c_normIL, normIL = c_normIL)
(HRT) The HRT object of which the parameters should be calculated
(Numeric) The overall arithmetic mean of the interval length of the measurement to normalise TS
(Numeric) The interval length to which TS should be normalised
(HRT) An HRT object with (re)calculated HRT parameters
This method is a wrapper for the methods calcTO and calcTS.